@@ -30,11 +30,11 @@ module PuppetStrings::Markdown
       end
     end
 
-    def error_type(r)
+    def error_type(r) # rubocop:disable Naming/UncommunicativeMethodParamName
       "`#{r.split(' ')[0]}`"
     end
 
-    def error_text(r)
+    def error_text(r) # rubocop:disable Naming/UncommunicativeMethodParamName
       "#{r.split(' ').drop(1).join(' ')}"
     end
   end
