@@ -18,7 +18,8 @@ class PuppetStrings::Yard::Handlers::Ruby::Base < YARD::Handlers::Ruby::Base
     when :label
       node.source[0..-2]
     when :dyna_symbol
-      node.source
+      content = node.jump(:tstring_content)
+      content.nil? ? node.source : content.source
     when :string_literal
       content = node.jump(:tstring_content)
       return content.source if content != node
@@ -33,6 +34,16 @@ class PuppetStrings::Yard::Handlers::Ruby::Base < YARD::Handlers::Ruby::Base
       end
 
       source
+    when :regexp_literal
+      node.source
     end
   end
+
+  def get_name(statementobject, statementtype)
+    parameters = statementobject.parameters(false)
+    raise YARD::Parser::UndocumentableError, "Expected at least one parameter to #{statementtype} at #{statementobject.file}:#{statementobject.line}." if parameters.empty?
+    name = node_as_string(parameters.first)
+    raise YARD::Parser::UndocumentableError, "Expected a symbol or string literal for first parameter but found '#{parameters.first.type}' at #{statement.file}:#{statement.line}." unless name
+    name
+  end
 end
