@@ -22,8 +22,10 @@ class PuppetStrings::Yard::Parsers::JSON::Parser < YARD::Parser::Base
   def parse
     begin
       json = JSON.parse(source)
-      @statements.push(PuppetStrings::Yard::Parsers::JSON::TaskStatement.new(json, @source, @file))
-    rescue
+      # TODO: this should compare json to a Task metadata json-schema or perform some other hueristics
+      # to determine what type of statement it represents
+      @statements.push(PuppetStrings::Yard::Parsers::JSON::TaskStatement.new(json, @source, @file)) unless json.empty?
+    rescue  # rubocop:disable Style/RescueStandardError  Just catch everything
       log.error "Failed to parse #{@file}: "
       @statements = []
     end
